@@ -2253,7 +2253,11 @@ filter guidelines).
 
 sub packExtraHeadTags {
     my ( $self, $unpacked ) = @_;
-    return $unpacked if !$unpacked;
+    # If no more unpacked tags, remove the packed tags
+    if ( !$unpacked ) {
+        $self->update({ extraHeadTagsPacked => $unpacked });
+        return;
+    }
     my $packed  = $unpacked;
     HTML::Packer::minify( \$packed, {
         remove_newlines     => 1,
@@ -2516,6 +2520,21 @@ sub purgeCache {
 }
 
 
+#-------------------------------------------------------------------
+
+=head2 refused ( )
+
+Returns an error message to the user, wrapped in the user's style.  This is most useful for
+handling UI errors.  Privilege errors should be still be sent to $session->privilege.
+
+=cut
+
+sub refused {
+	my ($self) = @_;
+	return $self->{_session};
+}
+
+
 #-------------------------------------------------------------------
 
 =head2 session ( )
@@ -2911,16 +2930,23 @@ sub www_editSave {
 
     ##If this is a new asset (www_add), the parent may be locked.  We should still be able to add a new asset.
     my $isNewAsset = $session->form->process("assetId") eq "new" ? 1 : 0;
+    $session->log->warn("new asset: $isNewAsset");
+    $session->log->warn("canEdit: ". $self->canEdit);
+    $session->log->warn("validToken: ". $session->form->validToken);
+    $session->log->warn("userId: ". $session->user->userId);
+    $session->log->warn("ownerUserId: ". $self->get('ownerUserId'));
     return $session->privilege->locked() if (!$self->canEditIfLocked and !$isNewAsset);
     return $session->privilege->insufficient() unless $self->canEdit && $session->form->validToken;
-    if ($self->session->config("maximumAssets")) {
+    if ($self->session->config->get("maximumAssets")) {
         my ($count) = $self->session->db->quickArray("select count(*) from asset");
         my $i18n = WebGUI::International->new($self->session, "Asset");
-        return $self->session->style->userStyle($i18n->get("over max assets")) if ($self->session->config("maximumAssets") <= $count);
+        return $self->session->style->userStyle($i18n->get("over max assets")) if ( $self->session->config->get("maximumAssets") <= $count && $isNewAsset );
     }
     my $object;
     if ($isNewAsset) {
-        $object = $self->addChild({className=>$session->form->process("class","className")});	
+        my $className = $session->form->process("class","className");
+        return $session->privilege->insufficient() if ($isNewAsset && !$className->canAdd($session));
+        $object = $self->addChild({className=> $className});	
         return $self->www_view unless defined $object;
         $object->{_parent} = $self;
         $object->{_properties}{url} = undef;
