@@ -101,12 +101,26 @@ A boolean, that if true will not notify Spectre of the delete.
 =cut
 
 sub delete {
-	my $self = shift;
+	my $self       = shift;
+    my $session    = $self->session;
 	my $skipNotify = shift;
-	$self->session->db->write("delete from WorkflowInstanceScratch where instanceId=?",[$self->getId]);
-	$self->session->db->deleteRow("WorkflowInstance","instanceId",$self->getId);
-	WebGUI::Workflow::Spectre->new($self->session)->notify("workflow/deleteInstance",$self->getId) unless ($skipNotify);
-	undef $self;
+
+    if ( $self->hasNextActivity ) {
+        #We are deleting in the middle of a workflow - Get the current activity and call the cleanup routine
+        my $activity = $self->getNextActivity;
+        eval { $activity->cleanup($self) };
+        if ($@) {
+            $session->errorHandler->error("Caught exception executing cleanup routine which was not run on workflow activity ".$activity->getId." for instance ".$self->getId.".  The following error was reported: ".$@);
+        }
+    }
+
+	$session->db->write("delete from WorkflowInstanceScratch where instanceId=?",[$self->getId]);
+	$session->db->deleteRow("WorkflowInstance","instanceId",$self->getId);
+	WebGUI::Workflow::Spectre->new($session)->notify("workflow/deleteInstance",$self->getId) unless ($skipNotify);
+
+	# We will need to remember that we were deleted if we get realtime-run
+	# during start().
+	$self->{deleted} = 1;
 }
 
 #-------------------------------------------------------------------
@@ -645,7 +659,8 @@ sub start {
 		my $start = time();
 		my $status = "complete";
 		$log->info('Trying to execute workflow instance '.$self->getId.' in realtime.');
-		while ($status eq "complete" && ($start > time() -10)) { # how much can we run in 10 seconds
+		# If we got deleted in the middle, we need to stop.  This is a hack.
+		while (!$self->{deleted} && $status eq "complete" && ($start > time() -10)) { # how much can we run in 10 seconds
 			$status = $self->run;
 			$log->info('Completed activity for workflow instance '.$self->getId.' in realtime with return status of '.$status.'.');
 		}
