@@ -62,11 +62,14 @@ if ($] >= 5.008) {
 my $missingModule = 0;
 
 checkModule("LWP",                          5.833        );
+checkModule("HTML::Form",                   5.800,     2 );
+checkModule("Net::DNS",                     0.66,        );
 checkModule("HTTP::Request",                1.40         );
 checkModule("HTTP::Headers",                1.61         );
 checkModule("Test::More",                   0.82,      2 );
 checkModule("Test::MockObject",             1.02,      2 );
 checkModule("Test::Deep",                   0.095,       );
+checkModule("Test::LongString",             0.13,      2 );
 checkModule("Test::Exception",              0.27,      2 );
 checkModule("Test::Differences",            0.5,       2 );
 checkModule("Test::Class",                  0.31,      2 );
@@ -127,9 +130,9 @@ checkModule("Module::Find",                 "0.06"       );
 checkModule("Class::C3",                    "0.21"       );
 checkModule("Params::Validate",             "0.91"       );
 checkModule("Clone",                        "0.31"       );
-checkModule('HTML::Packer',                 "0.4"        );
-checkModule('JavaScript::Packer',           '0.04'       );
-checkModule('CSS::Packer',                  '0.2'        );
+checkModule('JavaScript::Packer',           '1.002'      );
+checkModule('CSS::Packer',                  '1.000'      );
+checkModule('HTML::Packer',                 "1.000"      );
 checkModule('Business::Tax::VAT::Validation', '0.20'     );
 checkModule('Crypt::SSLeay',                '0.57'       );
 checkModule('Scope::Guard',                 '0.03'       );
@@ -149,6 +152,7 @@ checkModule('IO::Socket::SSL',                           );
 checkModule('Net::Twitter',                 "3.13006"    );
 checkModule('PerlIO::eol',                  "0.14"       );
 checkModule('Monkey::Patch',                '0.03',    2 );
+checkModule('Data::ICal',                   '0.16'       );
 
 failAndExit("Required modules are missing, running no more checks.") if $missingModule;
 
